@@ -28,6 +28,10 @@ class EntityReferenceClass:
         self.relationships = relationships
         self.meta = meta
 
+        if self.pk is not None:
+            # entity_ref.pk can be a CharField or a UUIDField. Force to string for easier comparisons.
+            self.pk = str(self.pk)
+
     def __str__(self):
         return f'Type: {self.resource}; ID: {self.pk}; ' \
                f'attributes: {self.attributes}; relationships: {self.relationships}'
